<nav id="sidebarMenu" class="col-md-3 col-lg-2 d-md-block bg-light sidebar collapse">
    <div class="position-sticky pt-2">
        <ul class="nav flex-column" id="accordion">

            <?php
            $temp_accordion = array("rh-liste-salaries", "rh-historique-excel", "rh-upload-excel", "rh-import-to-temp", "stats");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
                core::elementMenuH6("rh", "Salariés", NULL, "col-salaries");
                echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-salaries" data-parent="#accordion">';
                    core::elementMenu("rh-liste-salaries", "/rh-liste-salaries.html", "RH : Liste des salariés");
                    core::elementMenu("rh-historique-excel", "/rh-historique-excel.html", "RH : Historique des Excels");
                (isset(salaries::excelGetInProgress()["name"])) ? core::elementMenu("rh-historique-excel", "/rh-import-to-temp.html", "RH : Reprise du traitement") : NULL;
                    core::elementMenu("stats", "/stats.html", "RH : Stats salariés");
                echo '</ul>';

            $temp_accordion = array("proweb-salaries", "proweb-historique-excel", "proweb-export-csv", "proweb-salaries-upload");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
            core::elementMenuH6("proweb", "ProWeb", NULL, "col-proweb");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-proweb" data-parent="#accordion">';
                core::elementMenu("proweb-salaries", "/proweb-salaries.html", "Proweb : Liste des salariés");
                core::elementMenu("proweb-historique-excel", "/proweb-historique-excel.html", "Proweb : Historique des Excels");
                core::elementMenu("proweb-export-csv", "/proweb-export-csv.html", "Proweb : Transfert des données");
            echo '</ul>';

            $temp_accordion = array("compte", "compte-historique-csv", "compte-upload");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
            core::elementMenuH6("compte", "Comptes bancaires", NULL, "col-banque");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-banque" data-parent="#accordion">';
                core::elementMenu("compte-1", "/compte-1.html", "Banque : Compte Courant ASC");
                core::elementMenu("compte-2", "/compte-2.html", "Banque : Compte Courant AEP");
                core::elementMenu("compte-3", "/compte-3.html", "Banque : Livret OBNL TRIPLEX");
                core::elementMenu("compte-4", "/compte-4.html", "Banque : Épargne financière");
                core::elementMenu("compte-historique-csv", "/compte-historique-csv.html", "Banque : Historique des CSV");
            echo '</ul>';

            $temp_accordion = array("documents", "document");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
            core::elementMenuH6("documents", "Documents", NULL, "col-documents");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-documents" data-parent="#accordion">';
                core::elementMenu("documents", "/documents.html", "Documents : Liste des documents");
            echo '</ul>';

            $temp_accordion = array("sociale-check-salarie");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
            core::elementMenuH6("sociale", "Accès services sociaux", NULL, "col-sociaux");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-sociaux" data-parent="#accordion">';
                core::elementMenu("sociale-check-salarie", "/sociale-check-salarie.html", "Validation d'un compte salarié");
            echo '</ul>';

            $temp_accordion = array("evenements", "evenement", "lotterys", "lottery");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
                core::elementMenuH6("evenements", "Evènements", NULL, "col-events");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-events" data-parent="#accordion">';
                core::elementMenu("evenements", "/evenements.html", "Listes des évènements");
                core::elementMenu("lotterys", "/lotterys.html", "Listes des tirages au sort");
            echo '</ul>';

            $temp_accordion = array("pratique");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
                core::elementMenuH6("pratique", "Pratiques", NULL, "col-practice");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-practice" data-parent="#accordion">';
                core::elementMenuLink("pratique", "https://corporatedirectory.capgemini.com/MyDirectory/portals/std/index-portal.jsp", "Corporate Directory");
                core::elementMenuLink("pratique", "https://www.cse-invent.com", "Site du CSE");
                core::elementMenuLink("pratique", "https://" . DOMAIN_EVENTS, "Emargement Salariés");
                core::elementMenuLink("pratique", "https://" . DOMAIN_CONTROL, "Emargement Contrôleur");
                core::elementMenuLink("pratique", "https://wiki.cse-invent.com", "Wiki CSE");
                core::elementMenuLink("pratique", "https://contact.cse-invent.com", "Contact CSE");
                core::elementMenuLink("pratique", "https://sender.cse-invent.com", "SendPortal CSE");
            echo '</ul>';

            $temp_accordion = array("user", "parametres", "maj", "parametre-users", "parametre-teams", "tags", "historique");
            (in_array(core::getGet("p"), $temp_accordion) or get::isDefautMenu($temp_accordion)) ? $_show = "show" : $_show = NULL;
                core::elementMenuH6("parametres", "Administration", NULL, "col-admin");
            echo '<ul class="collapse ' . $_show . ' list-unstyled" id="col-admin" data-parent="#accordion">';
                core::elementMenu("parametre-users", "/parametre-users.html", "Admin : Utilisateurs");
                core::elementMenu("parametre-teams", "/parametre-teams.html", "Admin : Groupes & Droits");
                core::elementMenu("tags", "/tags.html", "Admin : Tags");
                core::elementMenu("historique", "/historique.html", "Admin : Historique");
                core::elementMenu("parametres", "/parametres.html", "Admin : Paramètres");
                core::elementMenu("maj", "/maj.html", "Admin : Mise à jour");
            echo '</ul>';
            ?>
        </ul>
    </div>

    <div style="position: absolute; bottom: 0; margin: 0 0 5px 10px; color: gray;">
        <small>Chargement le <?php echo core::printDateTxt(); ?></small>
    </div>
</nav>